        function getT(rr,cc){
       if(rr==5 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260509 a 12</strong> UTC HH+018 (rango:012-024)<br><strong>control +<br>EPS</strong>';}
       if(rr==5 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260509 a 12</strong> UTC HH+018 (rango:012-024)<br>grupo: <strong>1</strong> representante: <strong>0</strong> miembros: 27 <strong>control</strong><br>0,2,3,4,5,6,8,10,11,13,15,16,17,22,24,26,27,28,31,32,34,35,38,40,43,49,50';}
       if(rr==5 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260509 a 12</strong> UTC HH+018 (rango:012-024)<br>grupo: <strong>2</strong> representante: <strong>41</strong> miembros: 17 <br>1,9,12,18,20,21,23,30,36,37,39,41,44,45,46,47,48';}
       if(rr==5 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260509 a 12</strong> UTC HH+018 (rango:012-024)<br>grupo: <strong>3</strong> representante: <strong>19</strong> miembros: 7 <br>7,14,19,25,29,33,42';}
       if(rr==40 && cc==0){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260509 a 12</strong> UTC HH+018 (rango:012-024)<br><strong>control +<br>EPS</strong>';}
       if(rr==40 && cc==1){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260509 a 12</strong> UTC HH+018 (rango:012-024)<br>grupo: <strong>1</strong> representante: <strong>0</strong> miembros: 27 <strong>control</strong><br>0,2,3,4,5,6,8,10,11,13,15,16,17,22,24,26,27,28,31,32,34,35,38,40,43,49,50';}
       if(rr==40 && cc==2){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260509 a 12</strong> UTC HH+018 (rango:012-024)<br>grupo: <strong>2</strong> representante: <strong>41</strong> miembros: 17 <br>1,9,12,18,20,21,23,30,36,37,39,41,44,45,46,47,48';}
       if(rr==40 && cc==3){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260509 a 12</strong> UTC HH+018 (rango:012-024)<br>grupo: <strong>3</strong> representante: <strong>19</strong> miembros: 7 <br>7,14,19,25,29,33,42';}
       if(rr==41 && cc==0){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260509 a 12</strong> UTC HH+018 (rango:012-024)<br><strong>control +<br>EPS</strong>';}
       if(rr==41 && cc==1){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260509 a 12</strong> UTC HH+018 (rango:012-024)<br>grupo: <strong>1</strong> representante: <strong>0</strong> miembros: 27 <strong>control</strong><br>0,2,3,4,5,6,8,10,11,13,15,16,17,22,24,26,27,28,31,32,34,35,38,40,43,49,50';}
       if(rr==41 && cc==2){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260509 a 12</strong> UTC HH+018 (rango:012-024)<br>grupo: <strong>2</strong> representante: <strong>41</strong> miembros: 17 <br>1,9,12,18,20,21,23,30,36,37,39,41,44,45,46,47,48';}
       if(rr==41 && cc==3){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260509 a 12</strong> UTC HH+018 (rango:012-024)<br>grupo: <strong>3</strong> representante: <strong>19</strong> miembros: 7 <br>7,14,19,25,29,33,42';}
       if(rr==42 && cc==0){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260509 a 12</strong> UTC HH+018 (rango:012-024)<br><strong>control +<br>EPS</strong>';}
       if(rr==42 && cc==1){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260509 a 12</strong> UTC HH+018 (rango:012-024)<br>grupo: <strong>1</strong> representante: <strong>0</strong> miembros: 27 <strong>control</strong><br>0,2,3,4,5,6,8,10,11,13,15,16,17,22,24,26,27,28,31,32,34,35,38,40,43,49,50';}
       if(rr==42 && cc==2){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260509 a 12</strong> UTC HH+018 (rango:012-024)<br>grupo: <strong>2</strong> representante: <strong>41</strong> miembros: 17 <br>1,9,12,18,20,21,23,30,36,37,39,41,44,45,46,47,48';}
       if(rr==42 && cc==3){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260509 a 12</strong> UTC HH+018 (rango:012-024)<br>grupo: <strong>3</strong> representante: <strong>19</strong> miembros: 7 <br>7,14,19,25,29,33,42';}
       if(rr==43 && cc==0){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260509 a 12</strong> UTC HH+018 (rango:012-024)<br><strong>control +<br>EPS</strong>';}
       if(rr==43 && cc==1){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260509 a 12</strong> UTC HH+018 (rango:012-024)<br>grupo: <strong>1</strong> representante: <strong>0</strong> miembros: 27 <strong>control</strong><br>0,2,3,4,5,6,8,10,11,13,15,16,17,22,24,26,27,28,31,32,34,35,38,40,43,49,50';}
       if(rr==43 && cc==2){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260509 a 12</strong> UTC HH+018 (rango:012-024)<br>grupo: <strong>2</strong> representante: <strong>41</strong> miembros: 17 <br>1,9,12,18,20,21,23,30,36,37,39,41,44,45,46,47,48';}
       if(rr==43 && cc==3){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260509 a 12</strong> UTC HH+018 (rango:012-024)<br>grupo: <strong>3</strong> representante: <strong>19</strong> miembros: 7 <br>7,14,19,25,29,33,42';}
}
